@@ -1723,7 +1723,7 @@ def run_cppi(risky_r = None, safe_rate = 0., m = 3, start = 100, floor = 0.8, dr
     start = 1000
     floor = 0.8
 
-    dates = aggregated_df.index
+    dates = risky_r.index
     n_steps = len(dates)
     account_value = start
     floor_value = start * floor
