@@ -52,6 +52,13 @@ def plot_multiple_time_series(data_df, error_message='no data available'):
         fig.append_trace(trace_sig, row=1, col=1)
 
     fig.update_layout(height=600, width=1600, title_text="Strategy performances",showlegend=True)
+    fig.update_layout(height=600, width=1600, showlegend=True, legend=dict(
+        orientation="h",
+        yanchor="bottom",
+        y=1.02,
+        xanchor="right",
+        x=1
+    ))
     fig.update_xaxes(rangeslider_visible=True)
     return fig
 
@@ -170,7 +177,78 @@ def plot_month_hit_ratio(month_dictionary, height=600 , width=1600, put_on_same_
     #if put_on_same_scale:
     #    fig.update_yaxes(range=[data_df[constituents].min().min(), data_df[constituents].max().max()])
 
+def plot_multiple_time_series_scatter(data_df, split =False, logy = True, title = 'Strategy performances', height=600 ,width=1600, put_on_same_scale = True, drop_na_inf = True):
+    palette = cycle(px.colors.qualitative.Bold)
+#    palette = cycle(px.colors.qualitative.Vivid)
+#    palette = cycle(px.colors.qualitative.Safe)
+#    data_df[~data_df.isin([np.nan, np.inf, -np.inf]).any(1)] = 0.
+    if drop_na_inf and not data_df.isin([np.nan, np.inf, -np.inf]).astype(int).sum(axis=0).sum(axis=0) == 0:
+        data_df.iloc[data_df.isin([np.nan, np.inf, -np.inf]).values] = 0.
+    if split:
+        fig = make_subplots(rows=1, cols=len(data_df.columns))
+        constituents = [col for col in data_df.columns if col not in ['date','Date']]
+        counter = 1
+        for me_constituent in constituents:
+            trace_sig = go.Scatter(
+                x=data_df.index,
+                y=data_df[me_constituent],
+                name=me_constituent,
+                opacity=0.8,
+                text=me_constituent,
+                hoverinfo='text',
+                mode='markers',
+                marker_color=next(palette)
+            )
+            fig.append_trace(trace_sig, row=1, col=counter)
+            if logy:
+                fig.update_yaxes(title_text="y-axis in logarithmic scale", type="log", row=1, col=counter)
+            counter = counter+1
 
+        fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
+        fig.update_layout(height=height, width=width, showlegend=True, legend=dict(
+            orientation="h",
+            yanchor="bottom",
+            y=1.02,
+            xanchor="right",
+            x=1
+        ))
+        fig.update_xaxes(rangeslider_visible=True)
+        if put_on_same_scale:
+            fig.update_yaxes(range=[data_df[constituents].min().min(), data_df[constituents].max().max()])
+
+
+        return fig
+    else:
+        fig = make_subplots(rows=1, cols=1)
+        constituents = [col for col in data_df.columns if col not in ['date','Date']]
+        for me_constituent in constituents:
+            trace_sig = go.Scatter(
+                x=data_df.index,
+                y=data_df[me_constituent],
+                name=me_constituent,
+                opacity=0.8,
+                text=me_constituent,
+                hoverinfo='text',
+                mode='markers',
+                marker_color=next(palette)
+            )
+            fig.append_trace(trace_sig, row=1, col=1)
+
+        if logy:
+            fig.update_yaxes(title_text="y-axis in logarithmic scale", type="log", row=1, col=1)
+        fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
+        fig.update_xaxes(rangeslider_visible=True)
+        fig.update_layout(height=height, width=width, showlegend=True, legend=dict(
+            orientation="h",
+            yanchor="bottom",
+            y=1.02,
+            xanchor="right",
+            x=1
+        ))
+        if put_on_same_scale:
+            fig.update_yaxes(range=[data_df[constituents].min().min(), data_df[constituents].max().max()])
+
+        return fig
 
 def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strategy performances', height=600 ,width=1600, put_on_same_scale = True, drop_na_inf = True):
     palette = cycle(px.colors.qualitative.Bold)
@@ -199,6 +277,13 @@ def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strat
             counter = counter+1
 
         fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
+        fig.update_layout(height=height, width=width, showlegend=True, legend=dict(
+            orientation="h",
+            yanchor="bottom",
+            y=1.02,
+            xanchor="right",
+            x=1
+        ))
         fig.update_xaxes(rangeslider_visible=True)
         if put_on_same_scale:
             fig.update_yaxes(range=[data_df[constituents].min().min(), data_df[constituents].max().max()])
@@ -224,6 +309,13 @@ def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strat
             fig.update_yaxes(title_text="y-axis in logarithmic scale", type="log", row=1, col=1)
         fig.update_layout(height=height, width=width, title_text=title,showlegend=True)
         fig.update_xaxes(rangeslider_visible=True)
+        fig.update_layout(height=height, width=width, showlegend=True, legend=dict(
+            orientation="h",
+            yanchor="bottom",
+            y=1.02,
+            xanchor="right",
+            x=1
+        ))
         if put_on_same_scale:
             fig.update_yaxes(range=[data_df[constituents].min().min(), data_df[constituents].max().max()])
 
@@ -244,6 +336,13 @@ def plot_multiple_turnover(data_df, ma = None):
         fig.append_trace(trace_sig, row=1, col=1)
 
     fig.update_layout(height=600, width=1600, title_text="Strategy performances",showlegend=True)
+    fig.update_layout(height=600, width=1600, showlegend=True, legend=dict(
+        orientation="h",
+        yanchor="bottom",
+        y=1.02,
+        xanchor="right",
+        x=1
+    ))
     fig.update_xaxes(rangeslider_visible=True)
     return fig
 
